@@ -1,20 +1,28 @@
 # -*- coding: utf-8 -*-
-"""Dataset widget to display the contents of a dataset
+"""Dataset widget to display the contents of a dataset."""
 
-Copyright (C) 2020 Philipp S. Sommer
+# Disclaimer
+# ----------
+#
+# Copyright (C) 2021 Helmholtz-Zentrum Hereon
+# Copyright (C) 2020-2021 Helmholtz-Zentrum Geesthacht
+#
+# This file is part of psy-view and is released under the GNU LGPL-3.O license.
+# See COPYING and COPYING.LESSER in the root of the repository for full
+# licensing details.
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License version 3.0 as
+# published by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU LGPL-3.0 license for more details.
+#
+# You should have received a copy of the GNU LGPL-3.0 license
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see https://www.gnu.org/licenses/."""
 from __future__ import annotations
 
 import os.path as osp
@@ -99,7 +107,7 @@ filename with strings like
 <li> <code>%i</code> for a continuous counter of the images</li>
 <li><code>%(name)s</code> for variable names</li>
 <li>or other netCDF attributes (see the
-  <a href="https://psyplot.readthedocs.io/en/latest/api/psyplot.project.html#psyplot.project.Project.export">
+  <a href="https://psyplot.github.io/psyplot/api/psyplot.project.html#psyplot.project.Project.export">
   examples of exporting psyplot projects</a>)</li>
 </ul>
 
